function sxt_fits_info,fits_in,iout=iout

;+
; NAME
;	sxt_fits_info
; PURPOSE
;	Create an index structure from a fits-header structure that
;	is compatible with get_info and SXT gt_xxx programs.
; CALLING SEQUENCE
;	info = sxt_fits_info(fits_in,iout=iout)
; INPUT
;	fits_in, the FITS header structure for SXT Legacy .fts files.
; OUTPUT
;	info, a string array identical to the output of get_info.pro
; OPTIONAL KEYWORD OUTPUT
;	iout, the limited SXT index structure.
; HISTORY
;	13-Dec-2004 LWA  Created from get_info2.pro
;-

n=n_elements(fits_in)
iitem=indgen(n)

item={time:0L,day:0,dp_mode:0B,dp_rate:0B,periph:0B,$
   explevmode:0B,imgparam:0B,shape_cmd:intarr(2)}
item=replicate(item,n)
item.time=fits_in.time
item.day=fits_in.day
item.dp_mode=fits_in.dp_mode
item.dp_rate=fits_in.dp_rate
item.periph=fits_in.periph
item.explevmode=fits_in.explevmo
item.imgparam=fits_in.imgparam
item.shape_cmd(0)=fits_in.shape_cm
item.shape_cmd(1)=fits_in.shape_sa

iout=item

info_array = gt_conv2str(iitem, fmt='(i4)', /str) + ' ' + fmt_tim(item) + $
                gt_dp_mode(item, space=2, /short) + '/' + gt_dp_rate(item, /string, /short) + $
                gt_filta(item, space=2) + '/' + gt_filtb(item, /string) + $
                gt_res(item, /space, /orig) + $
                gt_expmode(item, /space) + gt_comp(item, /short, /space) + $
                gt_dpe(item, /space) + gt_dpe(item, /str, /conv) + $
                gt_shape_cmd(item, /space)

return,info_array

end
